@@ -24,6 +24,30 @@ contrast(Oats.emm.n, "poly")
 ## ------------------------------------------------------------------------
 emmeans(Oats.lmer, pairwise ~ Variety)
 
+## ------------------------------------------------------------------------
+ins <- data.frame(
+    n = c(500, 1200, 100, 400, 500, 300),
+    size = factor(rep(1:3,2), labels = c("S","M","L")),
+    age = factor(rep(1:2, each = 3)),
+    claims = c(42, 37, 1, 101, 73, 14))
+ins.glm <- glm(claims ~ size + age + offset(log(n)), 
+               data = ins, family = "poisson")
+
+## ------------------------------------------------------------------------
+ref_grid(ins.glm)
+
+## ------------------------------------------------------------------------
+emmeans(ins.glm, "size", type = "response")
+
+## ------------------------------------------------------------------------
+emmeans(ins.glm, "size", type = "response", offset = 0)
+
+## ----eval = FALSE--------------------------------------------------------
+#  emmeans(ins.glm, "size", type = "response", at = list(n = 1))
+
+## ----eval = FALSE--------------------------------------------------------
+#  emmeans(ins.glm, "size", type = "response", offset = log(100))
+
 ## ------------------------------------------------------------------------
 require("ordinal")
 wine.clm <- clm(rating ~ temp + contact, scale = ~ judge,
